@@ -29,6 +29,7 @@ module Dalli
     # - :serializer - defaults to Marshal
     # - :compressor - defaults to zlib
     # - :cache_nils - defaults to false, if true Dalli will not treat cached nil values as 'not found' for #fetch operations.
+    # - :digest_class - defaults to Digest::MD5, allows you to pass in an object that responds to the hexdigest method, useful for injecting a FIPS compliant hash object.
     #
     def initialize(servers=nil, options={})
       @servers = normalize_servers(servers || ENV["MEMCACHE_SERVERS"] || '127.0.0.1:11211')
@@ -331,13 +332,15 @@ module Dalli
 
     ##
     # Normalizes the argument into an array of servers.
-    # If the argument is a string, it's expected that the URIs are comma separated e.g.
+    # If the argument is a string, or an array containing strings, it's expected that the URIs are comma separated e.g.
     # "memcache1.example.com:11211,memcache2.example.com:11211,memcache3.example.com:11211"
     def normalize_servers(servers)
-      if servers.is_a? String
-        return servers.split(",")
-      else
-        return servers
+      Array(servers).flat_map do |server|
+        if server.is_a? String
+          server.split(",")
+        else
+          server
+        end
       end
     end
 
@@ -378,8 +381,9 @@ module Dalli
       raise ArgumentError, "key cannot be blank" if !key || key.length == 0
       key = key_with_namespace(key)
       if key.length > 250
+        digest_class = @options[:digest_class] || ::Digest::MD5
         max_length_before_namespace = 212 - (namespace || '').size
-        key = "#{key[0, max_length_before_namespace]}:md5:#{Digest::MD5.hexdigest(key)}"
+        key = "#{key[0, max_length_before_namespace]}:md5:#{digest_class.hexdigest(key)}"
       end
       return key
     end
@@ -407,6 +411,9 @@ module Dalli
       rescue NoMethodError
         raise ArgumentError, "cannot convert :expires_in => #{opts[:expires_in].inspect} to an integer"
       end
+      if opts[:digest_class] && !opts[:digest_class].respond_to?(:hexdigest)
+        raise ArgumentError, "The digest_class object must respond to the hexdigest method"
+      end
       opts
     end
 
