@@ -2,6 +2,7 @@
 # frozen_string_literal: true
 require_relative 'helper'
 require 'connection_pool'
+require 'openssl'
 
 class MockUser
   def cache_key
@@ -50,6 +51,26 @@ describe 'ActiveSupport::Cache::DalliStore' do
       with_cache :expires_in => 5.minutes, :frob => 'baz' do
         assert_equal 'baz', @dalli.options[:frob]
       end
+
+      with_cache :expires_in => 5.minutes, :digest_class => OpenSSL::Digest::SHA1 do
+        assert_equal OpenSSL::Digest::SHA1, @dalli.options[:digest_class]
+      end
+    end
+
+    it 'uses valid digest_class option' do
+      with_cache :expires_in => 5.minutes, :digest_class => OpenSSL::Digest::SHA1 do
+        key = "k" * 300
+        dvalue = @dalli.fetch(key) { 123 }
+        assert_equal 123, dvalue
+      end
+    end
+
+    it 'uses a fallback digest_class' do
+      with_cache :expires_in => 5.minutes do
+        key = "k" * 300
+        dvalue = @dalli.fetch(key) { 123 }
+        assert_equal 123, dvalue
+      end
     end
 
     it_with_and_without_local_cache 'allow mute and silence' do
@@ -67,9 +88,9 @@ describe 'ActiveSupport::Cache::DalliStore' do
       assert_equal 'bar', @dalli.read('foo', nil)
       assert_equal 18, @dalli.fetch('lkjsadlfk', nil) { 18 }
       assert_equal 18, @dalli.fetch('lkjsadlfk', nil) { 18 }
-      assert_equal 1, @dalli.increment('lkjsa', 1, nil)
-      assert_equal 2, @dalli.increment('lkjsa', 1, nil)
-      assert_equal 1, @dalli.decrement('lkjsa', 1, nil)
+      assert_equal 1, @dalli.increment('lkjsa', 1)
+      assert_equal 2, @dalli.increment('lkjsa', 1)
+      assert_equal 1, @dalli.decrement('lkjsa', 1)
       assert_equal true, @dalli.delete('lkjsa')
     end
 
@@ -527,6 +548,16 @@ describe 'ActiveSupport::Cache::DalliStore' do
     assert_equal ["127.0.0.1:11211"], @dalli.instance_variable_get(:@data).instance_variable_get(:@servers)
   end
 
+  it 'normalizes servers passed in as comma separated' do
+    @dalli = ActiveSupport::Cache::DalliStore.new('server1:2,server3:4')
+    assert_equal ['server1:2', 'server3:4'], @dalli.instance_variable_get(:@data).instance_variable_get(:@servers)
+  end
+
+  it 'normalizes servers passed in as comma separated, nested in an array' do
+    @dalli = ActiveSupport::Cache::DalliStore.new(['server1:2,server3:4', 'server5:6'])
+    assert_equal ['server1:2', 'server3:4', 'server5:6'], @dalli.instance_variable_get(:@data).instance_variable_get(:@servers)
+  end
+
   it 'supports connection pooling' do
     with_cache :expires_in => 1, :namespace => 'foo', :compress => true, :pool_size => 3 do
       assert_nil @dalli.read('foo')
